#   include	"libregConfig.h"

#   include	<stdio.h>
#   include	<unistd.h>
#   include	<string.h>

#   include	<reg.h>

void regErrorMessage(char * s)
{
#ifdef ERRAVAIL
	error("regexp: %s", s);
#else
	fprintf(stderr, "regexp(3): %s", s);
	exit(1);
#endif
	/* NOTREACHED */
}
